@@ -48,9 +48,9 @@ def multiplot(*args, **kwargs):
     g = Gnuplot()
 
     for k,v in kwargs.items():
-        #print('set %s %s' %(k, v))
         g.cmd('set %s %s' %(k, v))
-        #g.set(**kwargs)
+    if 'multiplot' not in kwargs.keys():
+        g.cmd('set multiplot')
 
     #print(args)
     for subplot in args:
